/**********************************************************************************
 Persistence of Vision Ray Tracer Scene Description File
 File name   : MediaCloud_test.pov
 Version     : 3.71
 Description : getting a consistent cloud (and fog) code together.
               Based (partly, I think) on Gilles Tran's MakeClouds.
               
 Date        : May 2018
 Author      : Thomas A. M. de Groot
 E-mail      : 
 
 Copyright (C) 2018. All rights reserved.
 Use and/or modification of this scene is free, except for commercial purposes.
 Commercial distribution is not allowed without written permission from the author.
**********************************************************************************/

// Render settings 3.7 (right-click on a line below):
// +w800 +h640 +a0.3 +am2 +bm2 +bs8 +wt6

//=================================================================================
// VERSION
//=================================================================================
//#version 3.7;
#version unofficial patch 3.71; //UberPOV

//=================================================================================
// DEFAULTS AND INCLUDES
//=================================================================================
#default {pigment {rgb <1,0,0>}}

#include "colors.inc"
#include "rand.inc"
#include "functions.inc"
#include "transforms.inc"

//=================================================================================
// SCENE SWITCHES
//=================================================================================
#declare Rad            = on;		// Radiosity switch

#declare AspectRatio    = image_width/image_height;
#declare CamZoom        = 1;
#declare CamSky         = <0, 1, 0>;
#declare CamAng         = 90;	//39
#declare CamLoc         = <0, 10, -50>;
#declare CamLookAt      = <0.0, 20.0, 0.0>;


//=================================================================================
// GLOBAL SETTINGS
//=================================================================================
global_settings {
  assumed_gamma 1.0
  max_trace_level 5			//default [5]
  #if (Rad)
  radiosity {
    pretrace_start 0.08           // start pretrace at this size
    pretrace_end   0.004          // end pretrace at this size
    count 35                      // higher -> higher quality (1..1600) [35]
    nearest_count 5               // higher -> higher quality (1..10) [5]
    error_bound 1                 // higher -> smoother, less accurate [1.8]
    recursion_limit 1             // how much interreflections are calculated (1..5+) [3]
    low_error_factor .3           // reduce error_bound during last pretrace step
    gray_threshold 0.0            // increase for weakening colors (0..1) [0]
    minimum_reuse 0.015           // reuse of old radiosity samples [0.015]
    maximum_reuse 0.1							// new parameter 3.7 [0.2]
    brightness 1                  // brightness of radiosity effects (0..1) [1]

    adc_bailout 0.01/2
    normal off                    // take surface normals into account [off]
    media on                     // take media into account [off]
    always_sample off             // turn sampling in final trace off [on]
    //max_sample 1.0              // maximum brightness of samples
  }
  #end
  //noise_generator 2
}

//====================================================================================
// CAMERA AND LIGHT, ENVIRONMENT
//====================================================================================
camera {
  location  CamLoc
  sky       CamSky  
  up        CamSky
  direction z*CamZoom
  right     x*AspectRatio
  angle     CamAng
  look_at   CamLookAt
}

light_source {
  <0,0,0> 
  <1, 1, 1>*2 
  translate <0.2, 1, 0.2>*10e4
  parallel 
  point_at CamLookAt
}

sphere {
  <0,0,0>,1
  hollow
  no_shadow
  texture {
    pigment {
      gradient y
      color_map {
               [ 0.0  srgb <0.6,0.7,1.0>]
               [ 0.7  srgb <0.0,0.1,0.8>]
      }
    }
    finish {emission 1 diffuse 0}
  }
  scale 10e5
}

plane {y, 0 pigment {srgb <0.2, 0.5, 0.2>} finish {diffuse 0.7} hollow}

//========================================================================
//Cloud layer:

#declare C_Cloud = <252, 252, 253>/255;
#declare C_Sky3  = <225, 225, 226>/255;

#declare C_Scattering = C_Cloud*10;
#declare C_Absorption = (1-C_Cloud)*5;
#declare C_Emission   = C_Cloud*0.01;//C_Sky3*0.01;

#declare C_Scale    = 200;
#declare Turbulence = 0.15; //0.15; // cloud turbulence
#declare Lambda     = 3; // cloud lambda
#declare Omega      = 0.6; // cloud omega

#declare Cloud1 = 
box {
  <-0.5, 0, -0.5>, <0.5, 1.0, 0.5>
  texture {pigment {rgbt 1} finish {diffuse 0}}
  //texture {pigment {rgbt <1,0,0,0.9>} finish {diffuse 1}}
  hollow
  interior {
    media {
      scattering {1, rgb C_Scattering/C_Scale /*extinction 0.15*/}
      absorption rgb C_Absorption
      emission rgb C_Emission
      intervals 1
      samples 100
      density {
        density_file df3 "Scattered_03.df3"
        turbulence Turbulence
        lambda Lambda
        omega Omega
        interpolate 1
        translate <-0.5, 0.0, -0.5>
      }
    }
  }
  scale C_Scale
  scale <10, 0.5, 10>
  rotate y*0
  translate <0, 101, C_Scale*5>
}

Cloud1

//========================================================================
//Atmospheric haze under the cloud layer:

#declare C_Fog          = <250, 250, 250>/255;
#declare Fog_Scattering = C_Fog*0.1;
#declare Fog_Scale      = 200;

#declare Fog =
box {
  <-0.5, -1.0, -0.5>, <0.5, 0.0, 0.5>
  texture {pigment {rgbt 1} finish {diffuse 0}}
  hollow
  interior {
    media {
      scattering {1, rgb Fog_Scattering/Fog_Scale /*extinction 0.15*/}
      absorption rgb (1-C_Fog)*0.01
      intervals 1
      samples 100
    }
  }
  scale Fog_Scale
  scale <10, 1, 10>
  translate <0, 100, C_Scale*5>
}

Fog

